=======
Credits
=======

Development Lead
----------------

* Ross A. Beyer <rbeyer@seti.org>


Contributors
------------

* `Andrew Annex <https://github.com/AndrewAnnex>`_



Original Language Contributors
------------------------------

These individuals wrote the Perl and Java versions of the
programs and algorithms that these Python versions are written
to emulate.

* Eric Eliason
* Audrie Fennema
* Richard Leis
* Guy McArthur
* Sarah Mattson
* Michael Wendell


Acknowledgements
----------------
Thanks to Chris Schaller for guidance on how to
formulate the HiRISE Observation ID classes, based
on his own work in Java.

Also thanks to Chris Schaller and Rod Heyd for working
to get an Apache 2 license on the Perl and Java programs
so that the derived works in this library could be
created.

Portions of this software were developed with support from the
following sources from NASA Science Mission Directorate (SMD)
funding sources:

- Mars Reconnaissance Orbiter (MRO) High Resolution Imaging Science
  Experiment (HiRISE)
- NASA-USGS Inter-Agency Agreement to support the Python emulation work
  in 2021.
